Finitomata.Listener behaviour (Finitomata v0.35.0)

Copy Markdown View Source

The behaviour to be implemented and passed to use Finitomata to receive all the state transitions notifications.

Summary

Callbacks

To be called after a successful transition

Callbacks

after_transition(id, state, payload)

@callback after_transition(
  id :: Finitomata.fsm_name(),
  state :: Finitomata.Transition.state(),
  payload :: Finitomata.State.payload()
) :: :ok

To be called after a successful transition